==> react-sortable-tree-2.0.0.tgz: package/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

<a name="2.0.0"></a>
# [2.0.0](https://github.com/fritz-c/react-sortable-tree/compare/v1.8.1...v2.0.0) (2018-02-10)


### Bug Fixes

* put style.css file in the correct place ([30dedbd](https://github.com/fritz-c/react-sortable-tree/commit/30dedbd))


### Chores

* Merge branch 'brendanmoore-feature/remove-style-loader' ([16f7740](https://github.com/fritz-c/react-sortable-tree/commit/16f7740))


### BREAKING CHANGES

* from v2.0.0 on, you must import the css for the
component yourself, using `import 'react-sortable-tree/styles.css';`.
You only need to do this once in your application.



<a name="1.8.1"></a>
## [1.8.1](https://github.com/fritz-c/react-sortable-tree/compare/v1.8.0...v1.8.1) (2018-01-21)


### Bug Fixes

* rename parentNode callback param to nextParentNode ([24bf39d](https://github.com/fritz-c/react-sortable-tree/commit/24bf39d))



<a name="1.8.0"></a>
# [1.8.0](https://github.com/fritz-c/react-sortable-tree/compare/v1.7.0...v1.8.0) (2018-01-21)


### Features

* Parent node in onMoveNode callback ([537c6a4](https://github.com/fritz-c/react-sortable-tree/commit/537c6a4))



<a name="1.7.0"></a>
# [1.7.0](https://github.com/fritz-c/react-sortable-tree/compare/v1.6.0...v1.7.0) (2018-01-16)


### Features

* add onDragStateChanged callback ([2caa9d1](https://github.com/fritz-c/react-sortable-tree/commit/2caa9d1))
  
  onDragStateChanged is called when dragging begins and ends, so you can easily track the current state of dragging.<br />
  Thanks to [@wuweiweiwu](https://github.com/wuweiweiwu) for the contribution!



<a name="1.6.0"></a>
# [1.6.0](https://github.com/fritz-c/react-sortable-tree/compare/v1.5.5...v1.6.0) (2018-01-14)


### Features

* add more parameters to rowHeight. Fixes [#199](https://github.com/fritz-c/react-sortable-tree/issues/199) ([8ff0ff2](https://github.com/fritz-c/react-sortable-tree/commit/8ff0ff2))
  
  Thanks to [@wuweiweiwu](https://github.com/wuweiweiwu) for the contribution!



<a name="1.5.5"></a>
## [1.5.5](https://github.com/fritz-c/react-sortable-tree/compare/v1.5.4...v1.5.5) (2018-01-13)


### Bug Fixes

* expand tree for searches on initial mount. fixes [#223](https://github.com/fritz-c/react-sortable-tree/issues/223) ([64a984a](https://github.com/fritz-c/react-sortable-tree/commit/64a984a))



<a name="1.5.4"></a>
## [1.5.4](https://github.com/fritz-c/react-sortable-tree/compare/v1.5.3...v1.5.4) (2018-01-07)

### Bug Fixes

* UglifyJS enabled to remove dead code, which had been causing issues with some builds. If the presence of UglifyJS causes issues in your production builds, please refer to https://github.com/fritz-c/react-sortable-tree#if-it-throws-typeerror-fn-is-not-a-function-errors-in-production



<a name="1.5.3"></a>
## [1.5.3](https://github.com/fritz-c/react-sortable-tree/compare/v1.5.2...v1.5.3) (2017-12-09)


### Bug Fixes

* dragging past the bottom of the tree no longer slows down rendering ([3ce35f3](https://github.com/fritz-c/react-sortable-tree/commit/3ce35f3))



<a name="1.5.2"></a>
## [1.5.2](https://github.com/fritz-c/react-sortable-tree/compare/v1.5.1...v1.5.2) (2017-11-28)


### Bug Fixes

* correct positioning of full-width draggable rows ([00396d1](https://github.com/fritz-c/react-sortable-tree/commit/00396d1))



<a name="1.5.1"></a>
## [1.5.1](https://github.com/fritz-c/react-sortable-tree/compare/v1.5.0...v1.5.1) (2017-11-28)


### Bug Fixes

* prevent slowdown caused by invalid targetDepth when using maxDepth ([c21d4de](https://github.com/fritz-c/react-sortable-tree/commit/c21d4de)), closes [#194](https://github.com/fritz-c/react-sortable-tree/issues/194)



<a name="1.5.0"></a>
# [1.5.0](https://github.com/fritz-c/react-sortable-tree/compare/v1.4.0...v1.5.0) (2017-10-29)


### Bug Fixes

* Fix oblong collapse/expand button appearance on mobile safari ([62dfdec](https://github.com/fritz-c/react-sortable-tree/commit/62dfdec))


### Features

* enable the use of themes for simplified appearance customization ([d07c6a7](https://github.com/fritz-c/react-sortable-tree/commit/d07c6a7))



<a name="1.4.0"></a>
# [1.4.0](https://github.com/fritz-c/react-sortable-tree/compare/v1.3.1...v1.4.0) (2017-10-13)


### Features

* Add path argument to onVisibilityToggle callback ([25cd134](https://github.com/fritz-c/react-sortable-tree/commit/25cd134))



<a name="1.3.1"></a>
## [1.3.1](https://github.com/fritz-c/react-sortable-tree/compare/v1.3.0...v1.3.1) (2017-10-03)


### Bug Fixes

* Allow react[@16](https://github.com/16) ([9a31a03](https://github.com/fritz-c/react-sortable-tree/commit/9a31a03))



<a name="1.3.0"></a>
# [1.3.0](https://github.com/fritz-c/react-sortable-tree/compare/v1.2.2...v1.3.0) (2017-09-20)


### Features

* Provide more row parameters in rowHeight callback ([1b88b18](https://github.com/fritz-c/react-sortable-tree/commit/1b88b18))



<a name="1.2.2"></a>
## [1.2.2](https://github.com/fritz-c/react-sortable-tree/compare/v1.2.1...v1.2.2) (2017-09-12)


### Bug Fixes

* Specify version of react-dnd-html5-backend to avoid invalid package installs ([a09b611](https://github.com/fritz-c/react-sortable-tree/commit/a09b611))



<a name="1.2.1"></a>
## [1.2.1](https://github.com/fritz-c/react-sortable-tree/compare/v1.2.0...v1.2.1) (2017-09-06)


### Bug Fixes

* Allow children function in default renderer ([6f1dcac](https://github.com/fritz-c/react-sortable-tree/commit/6f1dcac))



<a name="1.2.0"></a>
# [1.2.0](https://github.com/fritz-c/react-sortable-tree/compare/v1.1.1...v1.2.0) (2017-08-12)


### Features

* Add `shouldCopyOnOutsideDrop` prop to enable copying of nodes that leave the tree ([d6a9be9](https://github.com/fritz-c/react-sortable-tree/commit/d6a9be9))



<a name="1.1.1"></a>
## [1.1.1](https://github.com/fritz-c/react-sortable-tree/compare/v1.1.0...v1.1.1) (2017-08-06)


### Bug Fixes

* **tree-to-tree:** Fix node depth when dragging between trees ([323ccad](https://github.com/fritz-c/react-sortable-tree/commit/323ccad))



<a name="1.1.0"></a>
# [1.1.0](https://github.com/fritz-c/react-sortable-tree/compare/v1.0.0...v1.1.0) (2017-08-05)


### Features

* **node-renderer:** Make title and subtitle insertable via props ([fff72c6](https://github.com/fritz-c/react-sortable-tree/commit/fff72c6))



<a name="1.0.0"></a>
# [1.0.0](https://github.com/fritz-c/react-sortable-tree/compare/v0.1.21...v1.0.0) (2017-08-05)


### Bug Fixes

* External node offset was shifted ([d1ae0eb](https://github.com/fritz-c/react-sortable-tree/commit/d1ae0eb))


### Code Refactoring

* get rid of `dndWrapExternalSource` api ([d103e9f](https://github.com/fritz-c/react-sortable-tree/commit/d103e9f))


### Features

* **tree-to-tree:** Enable tree-to-tree drag-and-drop ([6986a23](https://github.com/fritz-c/react-sortable-tree/commit/6986a23))
* Display droppable placeholder element when tree is empty ([2cd371c](https://github.com/fritz-c/react-sortable-tree/commit/2cd371c))
* Add `prevPath` and `prevTreeIndex` to the `onMoveNode` callback ([6986a23](https://github.com/fritz-c/react-sortable-tree/commit/6986a23))


### BREAKING CHANGES

* Trees that are empty now display a placeholder element
in their place instead of being simply empty.
* `dndWrapExternalSource` api no longer exists.
You can achieve the same functionality and more with react-dnd
APIs, as demonstrated in the storybook example.



<a name="0.1.21"></a>
## [0.1.21](https://github.com/fritz-c/react-sortable-tree/compare/v0.1.20...v0.1.21) (2017-07-15)


### Bug Fixes

* Remove console.log left in after development ([da27c47](https://github.com/fritz-c/react-sortable-tree/commit/da27c47))



See the GitHub [Releases](https://github.com/fritz-c/react-sortable-tree/releases) for information on updates.

==> react-sortable-tree-2.0.1-1.tgz: package/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

<a name="2.0.1"></a>
## [2.0.1](https://github.com/fritz-c/react-sortable-tree/compare/v2.0.0...v2.0.1) (2018-02-10)


### Bug Fixes

* restore highlight line appearance ([2c95205](https://github.com/fritz-c/react-sortable-tree/commit/2c95205))



<a name="2.0.0"></a>
# [2.0.0](https://github.com/fritz-c/react-sortable-tree/compare/v1.8.1...v2.0.0) (2018-02-10)


### BREAKING CHANGES

* from v2.0.0 on, you must import the css for the
component yourself, using `import 'react-sortable-tree/style.css';`.
You only need to do this once in your application.

* Support dropped for IE versions earlier than IE 11


<a name="1.8.1"></a>
## [1.8.1](https://github.com/fritz-c/react-sortable-tree/compare/v1.8.0...v1.8.1) (2018-01-21)


### Bug Fixes

* rename parentNode callback param to nextParentNode ([24bf39d](https://github.com/fritz-c/react-sortable-tree/commit/24bf39d))



<a name="1.8.0"></a>
# [1.8.0](https://github.com/fritz-c/react-sortable-tree/compare/v1.7.0...v1.8.0) (2018-01-21)


### Features

* Parent node in onMoveNode callback ([537c6a4](https://github.com/fritz-c/react-sortable-tree/commit/537c6a4))



<a name="1.7.0"></a>
# [1.7.0](https://github.com/fritz-c/react-sortable-tree/compare/v1.6.0...v1.7.0) (2018-01-16)


### Features

* add onDragStateChanged callback ([2caa9d1](https://github.com/fritz-c/react-sortable-tree/commit/2caa9d1))
  
  onDragStateChanged is called when dragging begins and ends, so you can easily track the current state of dragging.<br />
  Thanks to [@wuweiweiwu](https://github.com/wuweiweiwu) for the contribution!



<a name="1.6.0"></a>
# [1.6.0](https://github.com/fritz-c/react-sortable-tree/compare/v1.5.5...v1.6.0) (2018-01-14)


### Features

* add more parameters to rowHeight. Fixes [#199](https://github.com/fritz-c/react-sortable-tree/issues/199) ([8ff0ff2](https://github.com/fritz-c/react-sortable-tree/commit/8ff0ff2))
  
  Thanks to [@wuweiweiwu](https://github.com/wuweiweiwu) for the contribution!



<a name="1.5.5"></a>
## [1.5.5](https://github.com/fritz-c/react-sortable-tree/compare/v1.5.4...v1.5.5) (2018-01-13)


### Bug Fixes

* expand tree for searches on initial mount. fixes [#223](https://github.com/fritz-c/react-sortable-tree/issues/223) ([64a984a](https://github.com/fritz-c/react-sortable-tree/commit/64a984a))



<a name="1.5.4"></a>
## [1.5.4](https://github.com/fritz-c/react-sortable-tree/compare/v1.5.3...v1.5.4) (2018-01-07)

### Bug Fixes

* UglifyJS enabled to remove dead code, which had been causing issues with some builds. If the presence of UglifyJS causes issues in your production builds, please refer to https://github.com/fritz-c/react-sortable-tree#if-it-throws-typeerror-fn-is-not-a-function-errors-in-production



<a name="1.5.3"></a>
## [1.5.3](https://github.com/fritz-c/react-sortable-tree/compare/v1.5.2...v1.5.3) (2017-12-09)


### Bug Fixes

* dragging past the bottom of the tree no longer slows down rendering ([3ce35f3](https://github.com/fritz-c/react-sortable-tree/commit/3ce35f3))



<a name="1.5.2"></a>
## [1.5.2](https://github.com/fritz-c/react-sortable-tree/compare/v1.5.1...v1.5.2) (2017-11-28)


### Bug Fixes

* correct positioning of full-width draggable rows ([00396d1](https://github.com/fritz-c/react-sortable-tree/commit/00396d1))



<a name="1.5.1"></a>
## [1.5.1](https://github.com/fritz-c/react-sortable-tree/compare/v1.5.0...v1.5.1) (2017-11-28)


### Bug Fixes

* prevent slowdown caused by invalid targetDepth when using maxDepth ([c21d4de](https://github.com/fritz-c/react-sortable-tree/commit/c21d4de)), closes [#194](https://github.com/fritz-c/react-sortable-tree/issues/194)



<a name="1.5.0"></a>
# [1.5.0](https://github.com/fritz-c/react-sortable-tree/compare/v1.4.0...v1.5.0) (2017-10-29)


### Bug Fixes

* Fix oblong collapse/expand button appearance on mobile safari ([62dfdec](https://github.com/fritz-c/react-sortable-tree/commit/62dfdec))


### Features

* enable the use of themes for simplified appearance customization ([d07c6a7](https://github.com/fritz-c/react-sortable-tree/commit/d07c6a7))



<a name="1.4.0"></a>
# [1.4.0](https://github.com/fritz-c/react-sortable-tree/compare/v1.3.1...v1.4.0) (2017-10-13)


### Features

* Add path argument to onVisibilityToggle callback ([25cd134](https://github.com/fritz-c/react-sortable-tree/commit/25cd134))



<a name="1.3.1"></a>
## [1.3.1](https://github.com/fritz-c/react-sortable-tree/compare/v1.3.0...v1.3.1) (2017-10-03)


### Bug Fixes

* Allow react[@16](https://github.com/16) ([9a31a03](https://github.com/fritz-c/react-sortable-tree/commit/9a31a03))



<a name="1.3.0"></a>
# [1.3.0](https://github.com/fritz-c/react-sortable-tree/compare/v1.2.2...v1.3.0) (2017-09-20)


### Features

* Provide more row parameters in rowHeight callback ([1b88b18](https://github.com/fritz-c/react-sortable-tree/commit/1b88b18))



<a name="1.2.2"></a>
## [1.2.2](https://github.com/fritz-c/react-sortable-tree/compare/v1.2.1...v1.2.2) (2017-09-12)


### Bug Fixes

* Specify version of react-dnd-html5-backend to avoid invalid package installs ([a09b611](https://github.com/fritz-c/react-sortable-tree/commit/a09b611))



<a name="1.2.1"></a>
## [1.2.1](https://github.com/fritz-c/react-sortable-tree/compare/v1.2.0...v1.2.1) (2017-09-06)


### Bug Fixes

* Allow children function in default renderer ([6f1dcac](https://github.com/fritz-c/react-sortable-tree/commit/6f1dcac))



<a name="1.2.0"></a>
# [1.2.0](https://github.com/fritz-c/react-sortable-tree/compare/v1.1.1...v1.2.0) (2017-08-12)


### Features

* Add `shouldCopyOnOutsideDrop` prop to enable copying of nodes that leave the tree ([d6a9be9](https://github.com/fritz-c/react-sortable-tree/commit/d6a9be9))



<a name="1.1.1"></a>
## [1.1.1](https://github.com/fritz-c/react-sortable-tree/compare/v1.1.0...v1.1.1) (2017-08-06)


### Bug Fixes

* **tree-to-tree:** Fix node depth when dragging between trees ([323ccad](https://github.com/fritz-c/react-sortable-tree/commit/323ccad))



<a name="1.1.0"></a>
# [1.1.0](https://github.com/fritz-c/react-sortable-tree/compare/v1.0.0...v1.1.0) (2017-08-05)


### Features

* **node-renderer:** Make title and subtitle insertable via props ([fff72c6](https://github.com/fritz-c/react-sortable-tree/commit/fff72c6))



<a name="1.0.0"></a>
# [1.0.0](https://github.com/fritz-c/react-sortable-tree/compare/v0.1.21...v1.0.0) (2017-08-05)


### Bug Fixes

* External node offset was shifted ([d1ae0eb](https://github.com/fritz-c/react-sortable-tree/commit/d1ae0eb))


### Code Refactoring

* get rid of `dndWrapExternalSource` api ([d103e9f](https://github.com/fritz-c/react-sortable-tree/commit/d103e9f))


### Features

* **tree-to-tree:** Enable tree-to-tree drag-and-drop ([6986a23](https://github.com/fritz-c/react-sortable-tree/commit/6986a23))
* Display droppable placeholder element when tree is empty ([2cd371c](https://github.com/fritz-c/react-sortable-tree/commit/2cd371c))
* Add `prevPath` and `prevTreeIndex` to the `onMoveNode` callback ([6986a23](https://github.com/fritz-c/react-sortable-tree/commit/6986a23))


### BREAKING CHANGES

* Trees that are empty now display a placeholder element
in their place instead of being simply empty.
* `dndWrapExternalSource` api no longer exists.
You can achieve the same functionality and more with react-dnd
APIs, as demonstrated in the storybook example.



<a name="0.1.21"></a>
## [0.1.21](https://github.com/fritz-c/react-sortable-tree/compare/v0.1.20...v0.1.21) (2017-07-15)


### Bug Fixes

* Remove console.log left in after development ([da27c47](https://github.com/fritz-c/react-sortable-tree/commit/da27c47))



See the GitHub [Releases](https://github.com/fritz-c/react-sortable-tree/releases) for information on updates.
